@@ -1,20 +1,21 @@
 # -*- coding: utf-8 -*-
 
-from aiohttp import ClientSession, TCPConnector
 import asyncio
-from requests import Session
 
 from .async_init import AsyncInitObject
+from .sessions import AsyncSession, SyncSession
 
 from types import TracebackType
 from typing import (
     Any,
     Coroutine,
+    Dict,
     Generator,
     Generic,
     Iterable,
     List,
     Mapping,
+    NoReturn,
     Optional,
     Set,
     Tuple,
@@ -26,31 +27,21 @@ from typing import (
 __all__ = (
     "AsyncClient",
     "SyncClient",
+    "make_headers",
 )
 
-TRUST_ENV = True
-
 
 class AsyncClient(AsyncInitObject):
-    async def __init__(self) -> None:
-        self.loop = asyncio.get_event_loop()
-
-        self.session = ClientSession(
-            loop=self.loop,
-            # connector=TCPConnector(ttl_dns_cache=60),
-            trust_env=TRUST_ENV,
-        )
+    async def __init__(self, token: str) -> None:
+        self.session = await AsyncSession(token)
 
     async def close(self) -> None:
-        if not self.closed:
-            await self.session.close()
-            # Zero-sleep to allow underlying connections to close
-            await asyncio.sleep(0)
+        """Close session"""
+        await self.session.close()
 
     @property
     def closed(self) -> bool:
-        """
-        Is client session closed.
+        """Is client session closed.
         A readonly property.
         """
         return self.session.closed
@@ -76,24 +67,19 @@ class AsyncClient(AsyncInitObject):
 
 
 class SyncClient:
-    def __init__(self) -> None:
-        self._closed = False
-
-        self.session = Session()
-        self.session.trust_env = TRUST_ENV
+    def __init__(self, token: str) -> None:
+        self.session = SyncSession(token)
 
     def close(self) -> None:
-        if not self.closed:
-            self.session.close()
-            self._closed = True
+        """Close session"""
+        self.session.close()
 
     @property
     def closed(self) -> bool:
-        """
-        Is client session closed.
+        """Is client session closed.
         A readonly property.
         """
-        return self._closed
+        return self.session.closed
 
     def __enter__(self) -> "SyncClient":
         return self
